use crate::{
    config::UserConfig,
    linux::{arch_chroot, systemd_service_enable},
    pkg::install_pkgs,
    print_status,
};

/// Setup docker on the system
pub fn setup_docker(conf: &[UserConfig]) {
    print_status("Setting up Docker");
    install_pkgs(&["docker", "docker-compose"]);

    systemd_service_enable("docker.service");

    for user in conf {
        if user.docker.unwrap_or_default() {
            arch_chroot(
                &vec!["usermod", "-a", "-G", "docker", user.name.as_str()],
                None,
                false,
            );
        }
    }
}
