use crate::{
    config::{InstallConfig, InstallMode},
    linux::{arch_chroot, run_command_noerr, systemd_service_enable},
    pkg::install_pkgs,
    print_status,
};

pub fn setup_virtualization(conf: &InstallConfig) {
    let user_conf = if let Some(user_conf) = &conf.user {
        user_conf.clone()
    } else {
        Vec::new()
    };

    install_pkgs(&["libvirt", "swtpm", "qemu-base"]);

    if matches!(conf.general.mode, InstallMode::Desktop) {
        install_pkgs(&["virt-manager"]);
    }

    systemd_service_enable("libvirtd.service");

    for user in user_conf {
        if user.virtualization.unwrap_or_default() {
            arch_chroot(
                &vec!["usermod", "-a", "-G", "libvirt", user.name.as_str()],
                None,
                false,
            );
        }
    }
}

/// Setup guest utils if running inside a VM
pub fn setup_vm() {
    let res = run_command_noerr(&["systemd-detect-virt", "--vm"], None, false);
    let is_vm = res.0.trim();

    match is_vm {
        "qemu" | "kvm" => {
            print_status("Detected KVM. Installing utils");
            install_pkgs(&["qemu-guest-agent", "spice-vdagent"]);
            systemd_service_enable("qemu-guest-agent.service");
            systemd_service_enable("spice-vdagentd.service");
        }
        _ => {}
    }
}
