use crate::linux::{arch_chroot, run_command};

pub const DESKTOP_PKG: [&str; 17] = [
    // Desktop
    "plasma",
    "sddm",
    // Sound
    "pipewire",
    "pipewire-alsa",
    "pipewire-pulse",
    "pipewire-jack",
    "wireplumber",
    // Applications
    "konsole",
    "dolphin",
    "ffmpegthumbs",
    "kate",
    "okular",
    "gwenview",
    "ark",
    "flatpak",
    // Misc
    "navos/navos",
    "man",
];

pub const SERVER_PKG: [&str; 2] = ["tmux", "navos/navos"];

/// Install packages to the chroot environment at `/mnt`
pub fn install_pkgs(pkg: &[&str]) {
    let mut cmd = vec!["pacman", "-Syu"];

    cmd.push("--noconfirm");
    cmd.extend_from_slice(pkg);

    arch_chroot(&cmd, None, true);
}

// PACSTRAP

/// Initial system pacstrap
pub fn pacstrap_at(dir: &str, kernel: Option<&String>, pkg: &[String]) {
    // TODO : rearrange pkgs + minify
    let mut cmd: Vec<&str> = vec!["pacstrap", "-K", dir, "base"];

    let linux_kernel = "linux".to_string();
    let kernel = kernel.unwrap_or(&linux_kernel);
    let headers = format!("{kernel}-headers");
    cmd.extend(&[kernel.as_str(), headers.as_str()]);

    #[cfg(target_arch = "aarch64")]
    {
        cmd.extend(&["archlinuxarm-keyring"]);
    }

    cmd.extend(
        pkg.iter()
            .map(std::string::String::as_str)
            .collect::<Vec<_>>(),
    );

    run_command(&cmd, None, true);
}
